Learn R Programming

pudu (version 0.1.0)

pudu-package: pudu: C++ Tools for Cleaning Strings

Description

Provides function declarations and inline function definitions that facilitate cleaning strings in C++ code before passing them to R.

Arguments

Author

Maintainer: Mauricio Vargas Sepulveda m.sepulveda@mail.utoronto.ca (ORCID)

Other contributors:

  • Munk School of Global Affairs and Public Policy [funder]

See Also